.. Copyright 2021 CMakePP
..
.. Licensed under the Apache License, Version 2.0 (the "License");
.. you may not use this file except in compliance with the License.
.. You may obtain a copy of the License at
..
.. http://www.apache.org/licenses/LICENSE-2.0
..
.. Unless required by applicable law or agreed to in writing, software
.. distributed under the License is distributed on an "AS IS" BASIS,
.. WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
.. See the License for the specific language governing permissions and
.. limitations under the License.
..
**********************
Documenting a Variable
**********************

CMinx supports documenting variables. The process is identical to documenting a
function or macro, except that the documentation comment precedes a ``set``
command. An example:

.. literalinclude:: ../../../tests/test_samples/variable.cmake
   :language: cmake

which generates:

.. literalinclude:: ../../../tests/test_samples/corr_rst/variable.rst
   :language: rst
